@@ -1,6 +1,7 @@
 from motor.motor_asyncio import AsyncIOMotorClient
 import redis
-from .setting import load_config
+# from .setting import load_config
+from setting import load_config
 
 CONF = load_config()
 
